@@ -1,5 +1,4 @@
 import os
-import re
 import sys
 
 from pipenv import environments
@@ -23,7 +22,6 @@ from pipenv.cli.options import (
     upgrade_options,
     verbose_option,
 )
-from pipenv.utils.dependencies import get_lockfile_section_using_pipfile_category
 from pipenv.utils.environment import load_dot_env
 from pipenv.utils.processes import subprocess_run
 from pipenv.vendor import click
@@ -243,8 +241,6 @@ def install(state, **kwargs):
         requirementstxt=state.installstate.requirementstxt,
         pre=state.installstate.pre,
         deploy=state.installstate.deploy,
-        keep_outdated=state.installstate.keep_outdated,
-        selective_upgrade=state.installstate.selective_upgrade,
         index_url=state.index,
         packages=state.installstate.packages,
         editable_packages=state.installstate.editables,
@@ -321,7 +317,6 @@ def uninstall(ctx, state, all_dev=False, all=False, **kwargs):
         lock=not state.installstate.skip_lock,
         all_dev=all_dev,
         all=all,
-        keep_outdated=state.installstate.keep_outdated,
         pypi_mirror=state.pypi_mirror,
         categories=state.installstate.categories,
         ctx=ctx,
@@ -370,7 +365,6 @@ def lock(ctx, state, **kwargs):
         state.project,
         clear=state.clear,
         pre=pre,
-        keep_outdated=state.installstate.keep_outdated,
         pypi_mirror=state.pypi_mirror,
         write=not state.quiet,
         categories=state.installstate.categories,
@@ -583,7 +577,6 @@ def update(ctx, state, bare=False, dry_run=None, outdated=False, **kwargs):
         clear=state.clear,
         pre=state.installstate.pre,
         pypi_mirror=state.pypi_mirror,
-        keep_outdated=state.installstate.keep_outdated,
         system=False,
         packages=state.installstate.packages,
         editable_packages=state.installstate.editables,
@@ -680,7 +673,6 @@ def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
         dev=state.installstate.dev,
         python=state.python,
         bare=bare,
-        dont_upgrade=(not state.installstate.keep_outdated),
         user=user,
         clear=state.clear,
         unused=unused,
@@ -780,40 +772,17 @@ def verify(state):
 def requirements(
     state, dev=False, dev_only=False, hash=False, exclude_markers=False, categories=""
 ):
-    from pipenv.utils.dependencies import convert_deps_to_pip
+    from pipenv.routines.requirements import generate_requirements
 
-    lockfile = state.project.load_lockfile(expand_env_vars=False)
-
-    for i, package_index in enumerate(lockfile["_meta"]["sources"]):
-        prefix = "-i" if i == 0 else "--extra-index-url"
-        echo(" ".join([prefix, package_index["url"]]))
-
-    deps = {}
-    categories_list = re.split(r", *| ", categories) if categories else []
-
-    if categories_list:
-        for category in categories_list:
-            category = get_lockfile_section_using_pipfile_category(category.strip())
-            deps.update(lockfile.get(category, {}))
-    else:
-        if dev or dev_only:
-            deps.update(lockfile["develop"])
-        if not dev_only:
-            deps.update(lockfile["default"])
-
-    pip_deps = convert_deps_to_pip(
-        deps,
-        project=None,
-        include_index=False,
+    generate_requirements(
+        project=state.project,
+        dev=dev,
+        dev_only=dev_only,
         include_hashes=hash,
         include_markers=not exclude_markers,
+        categories=categories,
     )
 
-    for d in pip_deps:
-        echo(d)
-
-    sys.exit(0)
-
 
 if __name__ == "__main__":
     cli()
