@@ -614,7 +614,15 @@ def parse_packages(packages, pre, clear, system, requirements_dir=None):
 
 
 def resolve_packages(
-    pre, clear, verbose, system, requirements_dir, packages, category, constraints=None
+    pre,
+    clear,
+    verbose,
+    system,
+    write,
+    requirements_dir,
+    packages,
+    category,
+    constraints=None,
 ):
     from pipenv.utils.internet import create_mirror_source, replace_pypi_sources
     from pipenv.utils.resolver import resolve_deps
@@ -662,11 +670,42 @@ def resolve_packages(
         requirements_dir=requirements_dir,
     )
     results = clean_results(results, resolver, project, category)
+    if write:
+        with open(write, "w") as fh:
+            if not results:
+                json.dump([], fh)
+            else:
+                json.dump(results, fh)
     if results:
         return results
     return []
 
 
+def _main(
+    pre,
+    clear,
+    verbose,
+    system,
+    write,
+    requirements_dir,
+    packages,
+    parse_only=False,
+    category=None,
+):
+    if parse_only:
+        parse_packages(
+            packages,
+            pre=pre,
+            clear=clear,
+            system=system,
+            requirements_dir=requirements_dir,
+        )
+    else:
+        resolve_packages(
+            pre, clear, verbose, system, write, requirements_dir, packages, category
+        )
+
+
 def main(argv=None):
     parser = get_parser()
     parsed, remaining = parser.parse_known_args(argv)
@@ -682,13 +721,15 @@ def main(argv=None):
     os.environ["PYTHONIOENCODING"] = "utf-8"
     os.environ["PYTHONUNBUFFERED"] = "1"
     parsed = handle_parsed_args(parsed)
-    resolve_packages(
+    _main(
         parsed.pre,
         parsed.clear,
         parsed.verbose,
         parsed.system,
+        parsed.write,
         parsed.requirements_dir,
         parsed.packages,
+        parse_only=parsed.parse_only,
         category=parsed.category,
     )
 
